@@ -151,12 +151,11 @@ void MainShellTest::initTestCase()
     const QString serviceName = QStringLiteral("org.kde.okular-") + myPid;
     QVERIFY(bus->registerService(serviceName) == QDBusConnectionInterface::ServiceRegistered);
 #endif
-
     // Tell the presentationWidget and queryClose to not be annoying
-    KSharedConfigPtr c = KSharedConfig::openConfig();
-    KConfigGroup cg = c->group("Notification Messages");
-    cg.writeEntry("presentationInfo", false);
-    cg.writeEntry("ShowTabWarning", false);
+    KSharedConfigPtr c = KSharedConfig::openConfig(QStringLiteral("mainshelltest.kmessagebox"));
+    KConfigGroup cg = c->group("General");
+    cg.writeEntry("presentationInfo", 4);
+    cg.writeEntry("ShowTabWarning", 4);
 }
 
 void MainShellTest::cleanupTestCase()
@@ -314,7 +313,7 @@ void MainShellTest::testShell()
             QCOMPARE(partDocument(part2)->currentPage(), expectedPage);
             openUrls << part2->url().url();
 
-            for (const QString &path : qAsConst(paths)) {
+            for (const QString &path : std::as_const(paths)) {
                 QVERIFY(openUrls.contains(QStringLiteral("file://%1").arg(path)));
             }
         }
@@ -540,7 +539,7 @@ void MainShellTest::testSessionRestore()
     QList<Shell *> shells = getShells();
     QVERIFY(!shells.isEmpty());
     int numDocs = 0;
-    for (Shell *shell : qAsConst(shells)) {
+    for (Shell *shell : std::as_const(shells)) {
         QVERIFY(QTest::qWaitForWindowExposed(shell));
         numDocs += shell->m_tabs.size();
     }
@@ -560,7 +559,7 @@ void MainShellTest::testSessionRestore()
     int numWindows = 0;
     { // Scope for config so that we can reconstruct from file
         KConfig config(configFile.fileName(), KConfig::SimpleConfig);
-        for (Shell *shell : qAsConst(shells)) {
+        for (Shell *shell : std::as_const(shells)) {
             shell->savePropertiesInternal(&config, ++numWindows);
             // Windows aren't necessarily closed on shutdown, but we'll use
             // this as a way to trigger the destructor code, which is normally
@@ -574,8 +573,10 @@ void MainShellTest::testSessionRestore()
     QEventLoop eventLoop;
     QTimer::singleShot(100, &eventLoop, &QEventLoop::quit);
     eventLoop.exec(QEventLoop::AllEvents);
+    // Sometimes the event loop is not enough, so try a bit more to get deferred delete happen
+    QCoreApplication::sendPostedEvents(nullptr, QEvent::DeferredDelete);
     shells = getShells();
-    QVERIFY(shells.isEmpty());
+    QCOMPARE(shells.size(), 0);
 
     Okular::Settings::self()->setShellOpenFileInTabs(useTabsRestore);
 
@@ -593,7 +594,7 @@ void MainShellTest::testSessionRestore()
     shells = getShells();
     QVERIFY(!shells.isEmpty());
     numDocs = 0;
-    for (Shell *shell : qAsConst(shells)) {
+    for (Shell *shell : std::as_const(shells)) {
         QVERIFY(QTest::qWaitForWindowExposed(shell));
         numDocs += shell->m_tabs.size();
     }
