@@ -337,14 +337,16 @@ EditTextCommand::EditTextCommand(const QString &newContents, int newCursorPos, c
     if (m_prevCursorPos != m_prevAnchorPos) {
         qCDebug(OkularCoreDebug) << "OtherEdit, selection";
         m_editType = OtherEdit;
-    } else if (newContentsRightOfCursor() == oldContentsRightOfCursor() && newContentsLeftOfCursor() == oldContentsLeftOfCursor().left(oldContentsLeftOfCursor().length() - 1) && oldContentsLeftOfCursor().rightRef(1) != QLatin1Char('\n')) {
+    } else if (newContentsRightOfCursor() == oldContentsRightOfCursor() && newContentsLeftOfCursor() == oldContentsLeftOfCursor().left(oldContentsLeftOfCursor().length() - 1) &&
+               QStringView {oldContentsLeftOfCursor()}.right(1) != QLatin1Char('\n')) {
         qCDebug(OkularCoreDebug) << "CharBackspace";
         m_editType = CharBackspace;
     } else if (newContentsLeftOfCursor() == oldContentsLeftOfCursor() && newContentsRightOfCursor() == oldContentsRightOfCursor().right(oldContentsRightOfCursor().length() - 1) &&
-               oldContentsRightOfCursor().leftRef(1) != QLatin1Char('\n')) {
+               QStringView {oldContentsRightOfCursor()}.left(1) != QLatin1Char('\n')) {
         qCDebug(OkularCoreDebug) << "CharDelete";
         m_editType = CharDelete;
-    } else if (newContentsRightOfCursor() == oldContentsRightOfCursor() && newContentsLeftOfCursor().left(newContentsLeftOfCursor().length() - 1) == oldContentsLeftOfCursor() && newContentsLeftOfCursor().rightRef(1) != QLatin1Char('\n')) {
+    } else if (newContentsRightOfCursor() == oldContentsRightOfCursor() && newContentsLeftOfCursor().left(newContentsLeftOfCursor().length() - 1) == oldContentsLeftOfCursor() &&
+               QStringView {newContentsLeftOfCursor()}.right(1) != QLatin1Char('\n')) {
         qCDebug(OkularCoreDebug) << "CharInsert";
         m_editType = CharInsert;
     } else {
@@ -598,7 +600,7 @@ EditFormButtonsCommand::EditFormButtonsCommand(Okular::DocumentPrivate *docPriv,
     , m_prevButtonStates(QList<bool>())
 {
     setText(i18nc("Edit the state of a group of form buttons", "edit form button states"));
-    for (const FormFieldButton *formButton : qAsConst(m_formButtons)) {
+    for (const FormFieldButton *formButton : std::as_const(m_formButtons)) {
         m_prevButtonStates.append(formButton->state());
     }
 }
@@ -652,7 +654,7 @@ bool EditFormButtonsCommand::refreshInternalPageReferences(const QVector<Okular:
 
 void EditFormButtonsCommand::clearFormButtonStates()
 {
-    for (FormFieldButton *formButton : qAsConst(m_formButtons)) {
+    for (FormFieldButton *formButton : std::as_const(m_formButtons)) {
         formButton->setState(false);
     }
 }
