@@ -41,10 +41,12 @@ static QString popplerEnumToUserString(Poppler::CryptoSignBackend backend)
 
 std::optional<Poppler::CryptoSignBackend> PDFSettingsWidget::settingStringToPopplerEnum(QStringView backend)
 {
-    if (backend == QStringLiteral("NSS"))
+    if (backend == QStringLiteral("NSS")) {
         return Poppler::CryptoSignBackend::NSS;
-    if (backend == QStringLiteral("GPG"))
+    }
+    if (backend == QStringLiteral("GPG")) {
         return Poppler::CryptoSignBackend::GPG;
+    }
     return std::nullopt;
 }
 #endif
@@ -87,7 +89,7 @@ PDFSettingsWidget::PDFSettingsWidget(QWidget *parent)
         m_pdfsw.kcfg_SignatureBackend->setProperty("kcfg_property", QByteArray("currentData"));
 
         m_pdfsw.kcfg_SignatureBackend->setCurrentIndex(selected);
-        connect(m_pdfsw.kcfg_SignatureBackend, &QComboBox::currentTextChanged, [this](const QString &text) {
+        connect(m_pdfsw.kcfg_SignatureBackend, &QComboBox::currentTextChanged, this, [this](const QString &text) {
             auto backendEnum = settingStringToPopplerEnum(text);
             if (!backendEnum) {
                 return;
