@@ -357,7 +357,7 @@ void AnnotationActionHandlerPrivate::populateQuickAnnotations()
         q->deselectAllAnnotationActions();
     }
 
-    for (QAction *action : qAsConst(quickTools)) {
+    for (QAction *action : std::as_const(quickTools)) {
         aQuickTools->removeAction(action);
         aQuickToolsBar->removeAction(action);
         delete action;
@@ -759,7 +759,7 @@ AnnotationActionHandler::AnnotationActionHandler(PageViewAnnotator *parent, KAct
     ac->setDefaultShortcut(aFreehandLine, Qt::ALT + Qt::Key_8);
     ac->setDefaultShortcut(aArrow, Qt::ALT + Qt::Key_9);
     ac->setDefaultShortcut(aRectangle, Qt::ALT + Qt::Key_0);
-    ac->setDefaultShortcut(d->aAddToQuickTools, QKeySequence(Qt::CTRL + Qt::SHIFT + Qt::Key_B));
+    ac->setDefaultShortcut(d->aAddToQuickTools, QKeySequence((Qt::CTRL | Qt::SHIFT) + Qt::Key_B));
     d->updateConfigActions();
 
     connect(Okular::Settings::self(), &Okular::Settings::primaryAnnotationToolBarChanged, this, &AnnotationActionHandler::setupAnnotationToolBarVisibilityAction);
@@ -827,10 +827,10 @@ void AnnotationActionHandler::setToolsEnabled(bool on)
 void AnnotationActionHandler::setTextToolsEnabled(bool on)
 {
     d->textToolsEnabled = on;
-    for (QAction *ann : qAsConst(d->textTools)) {
+    for (QAction *ann : std::as_const(d->textTools)) {
         ann->setEnabled(on);
     }
-    for (QAction *ann : qAsConst(d->textQuickTools)) {
+    for (QAction *ann : std::as_const(d->textQuickTools)) {
         ann->setEnabled(on);
     }
 }
