@@ -1246,7 +1246,7 @@ void SignatureEdit::signUnsignedSignature()
         }                                                                                                                                                                                                                                      \
         BaseClass::leaveEvent(event);                                                                                                                                                                                                          \
     }                                                                                                                                                                                                                                          \
-    void FormClass::enterEvent(QEvent *event)                                                                                                                                                                                                  \
+    void FormClass::enterEvent(QEnterEvent *event)                                                                                                                                                                                             \
     {                                                                                                                                                                                                                                          \
         Okular::Action *act = m_ff->additionalAction(Okular::Annotation::CursorEntering);                                                                                                                                                      \
         if (act) {                                                                                                                                                                                                                             \
