@@ -357,14 +357,14 @@ public:
 
         // FIXME this is a bit arbitrary, try to figure out a better rule, potentially based in cm and not pixels?
         if (rect.width() * m_page->width() < 100 || rect.height() * m_page->height() < 100) {
-            const KMessageBox::ButtonCode answer = KMessageBox::questionYesNo(
+            const KMessageBox::ButtonCode answer = KMessageBox::questionTwoActions(
                 m_pageView,
                 xi18nc("@info", "A signature of this size may be too small to read. If you would like to create a potentially more readable signature, press <interface>Start over</interface> and draw a bigger rectangle."),
                 QString(),
                 KGuiItem(i18nc("@action:button", "Start Over")),
                 KGuiItem(i18nc("@action:button", "Sign")),
                 QStringLiteral("TooSmallDigitalSignatureQuestion"));
-            if (answer == KMessageBox::Yes) {
+            if (answer == KMessageBox::PrimaryAction) {
                 m_startOver = true;
                 return {};
             }
@@ -684,7 +684,7 @@ public:
             QColor col = m_engineColor;
             col.setAlphaF(0.5);
             painter->setBrush(col);
-            for (const Okular::NormalizedRect &r : qAsConst(*selection)) {
+            for (const Okular::NormalizedRect &r : std::as_const(*selection)) {
                 painter->drawRect(r.geometry((int)xScale, (int)yScale));
             }
         }
@@ -723,7 +723,7 @@ public:
             Okular::HighlightAnnotation *ha = new Okular::HighlightAnnotation();
             ha->setHighlightType(type);
             ha->setBoundingRectangle(Okular::NormalizedRect(rect, item()->uncroppedWidth(), item()->uncroppedHeight()));
-            for (const Okular::NormalizedRect &r : qAsConst(*selection)) {
+            for (const Okular::NormalizedRect &r : std::as_const(*selection)) {
                 Okular::HighlightAnnotation::Quad q;
                 q.setCapStart(false);
                 q.setCapEnd(false);
