@@ -33,6 +33,15 @@
 #include <KLocalizedString>
 #include <KMessageBox>
 #include <KSharedConfig>
+namespace
+{
+static constexpr char ConfigGroup[] = "Signature";
+static constexpr char ConfigBackgroundKey[] = "RecentBackgrounds";
+static constexpr char ConfigLastReason[] = "Reason";
+static constexpr char ConfigLastLocation[] = "Location";
+static constexpr char ConfigLastKeyNick[] = "KeyNick";
+
+}
 
 namespace SignaturePartUtils
 {
@@ -96,11 +105,9 @@ class RecentImagesModel : public QAbstractListModel
 {
     Q_OBJECT
 public:
-    static constexpr char ConfigGroup[] = "Signature";
-    static constexpr char ConfigKey[] = "RecentBackgrounds";
     RecentImagesModel()
     {
-        const auto recentList = KSharedConfig::openConfig()->group(QLatin1String(ConfigGroup)).readEntry<QStringList>(QLatin1String(ConfigKey), QStringList());
+        const auto recentList = KSharedConfig::openConfig()->group(QLatin1String(ConfigGroup)).readEntry<QStringList>(QLatin1String(ConfigBackgroundKey), QStringList());
         for (const auto &element : recentList) {
             if (QFile::exists(element)) { // maybe the image has been removed from disk since last invocation
                 m_storedElements.push_back(element);
@@ -199,7 +206,7 @@ public:
         while (elementsToStore.size() > 3) {
             elementsToStore.pop_back();
         }
-        KSharedConfig::openConfig()->group(QString::fromUtf8(ConfigGroup)).writeEntry(ConfigKey, elementsToStore);
+        KSharedConfig::openConfig()->group(QString::fromUtf8(ConfigGroup)).writeEntry(ConfigBackgroundKey, elementsToStore);
     }
 
 private:
@@ -225,8 +232,12 @@ std::optional<SigningInformation> getCertificateAndPasswordForSigning(PageView *
 
     QStandardItemModel items;
     QHash<QString, Okular::CertificateInfo> nickToCert;
-    int minWidth = -1;
-    for (const auto &cert : qAsConst(certs)) {
+    qsizetype minWidth = -1;
+    bool showIcons = false;
+    int selectIndex = 0;
+    auto config = KSharedConfig::openConfig();
+    const QString lastNick = config->group(ConfigGroup).readEntry<QString>(ConfigLastKeyNick, QString());
+    for (const auto &cert : std::as_const(certs)) {
         auto item = std::make_unique<QStandardItem>();
         QString commonName = cert.subjectInfo(Okular::CertificateInfo::CommonName, Okular::CertificateInfo::EmptyString::Empty);
         item->setData(commonName, Qt::UserRole);
@@ -235,18 +246,40 @@ std::optional<SigningInformation> getCertificateAndPasswordForSigning(PageView *
 
         minWidth = std::max(minWidth, std::max(cert.nickName().size(), emailAddress.size() + commonName.size()));
 
+        switch (cert.keyLocation()) {
+        case Okular::CertificateInfo::KeyLocation::Computer:
+            item->setData(QIcon::fromTheme(QStringLiteral("view-certificate")), Qt::DecorationRole);
+            showIcons = true;
+            break;
+        case Okular::CertificateInfo::KeyLocation::HardwareToken:
+            /* Better icon requested in https://bugs.kde.org/show_bug.cgi?id=428278*/
+            item->setData(QIcon::fromTheme(QStringLiteral("auth-sim")), Qt::DecorationRole);
+            showIcons = true;
+            break;
+        case Okular::CertificateInfo::KeyLocation::Unknown:; //
+            break;
+        case Okular::CertificateInfo::KeyLocation::Other:
+            break;
+        }
+
         item->setData(cert.nickName(), Qt::DisplayRole);
         item->setData(cert.subjectInfo(Okular::CertificateInfo::DistinguishedName, Okular::CertificateInfo::EmptyString::Empty), Qt::ToolTipRole);
         item->setEditable(false);
+        if (cert.nickName() == lastNick) {
+            selectIndex = items.rowCount();
+        }
         items.appendRow(item.release());
         nickToCert[cert.nickName()] = cert;
     }
 
     SelectCertificateDialog dialog(pageView);
+    auto keyDelegate = new KeyDelegate(dialog.ui->list);
+    keyDelegate->showIcon = showIcons;
+    dialog.ui->list->setItemDelegate(keyDelegate);
     QFontMetrics fm = dialog.fontMetrics();
     dialog.ui->list->setMinimumWidth(fm.averageCharWidth() * (minWidth + 5));
     dialog.ui->list->setModel(&items);
-    dialog.ui->list->selectionModel()->select(items.index(0, 0), QItemSelectionModel::Rows | QItemSelectionModel::ClearAndSelect);
+    dialog.ui->list->selectionModel()->select(items.index(selectIndex, 0), QItemSelectionModel::Rows | QItemSelectionModel::ClearAndSelect);
     if (items.rowCount() < 3) {
         auto rowHeight = dialog.ui->list->sizeHintForRow(0);
         dialog.ui->list->setFixedHeight(rowHeight * items.rowCount() + (items.rowCount() - 1) * dialog.ui->list->spacing() + dialog.ui->list->contentsMargins().top() + dialog.ui->list->contentsMargins().bottom());
@@ -295,6 +328,10 @@ std::optional<SigningInformation> getCertificateAndPasswordForSigning(PageView *
                 }
             }
         });
+        // needs to happen after textChanged connection on backgroundInput
+        if (haveRecent) {
+            dialog.ui->backgroundInput->setText(imagesModel.index(0, 0).data().toString());
+        }
 
         QObject::connect(dialog.ui->backgroundButton, &QPushButton::clicked, &dialog, [lineEdit = dialog.ui->backgroundInput]() {
             const auto supportedFormats = QImageReader::supportedImageFormats();
@@ -330,6 +367,8 @@ std::optional<SigningInformation> getCertificateAndPasswordForSigning(PageView *
             }
         });
     }
+    dialog.ui->reasonInput->setText(config->group(ConfigGroup).readEntry(ConfigLastReason, QString()));
+    dialog.ui->locationInput->setText(config->group(ConfigGroup).readEntry(ConfigLastLocation, QString()));
     auto result = dialog.exec();
 
     if (result == QDialog::Rejected) {
@@ -372,6 +411,9 @@ std::optional<SigningInformation> getCertificateAndPasswordForSigning(PageView *
     }
 
     if (passok) {
+        config->group(ConfigGroup).writeEntry(ConfigLastKeyNick, cert.nickName());
+        config->group(ConfigGroup).writeEntry(ConfigLastReason, dialog.ui->reasonInput->text());
+        config->group(ConfigGroup).writeEntry(ConfigLastLocation, dialog.ui->locationInput->text());
         return SigningInformation {std::make_unique<Okular::CertificateInfo>(std::move(cert)), password, documentPassword, dialog.ui->reasonInput->text(), dialog.ui->locationInput->text(), backGroundImage};
     }
     return std::nullopt;
@@ -385,7 +427,7 @@ QString getFileNameForNewSignedFile(PageView *pageView, Okular::Document *doc)
     const QString mimeTypeFilter = i18nc("File type name and pattern", "%1 (%2)", mimeType.comment(), mimeType.globPatterns().join(QLatin1Char(' ')));
 
     const QUrl currentFileUrl = doc->currentDocument();
-    const QString localFilePathIfAny = currentFileUrl.isLocalFile() ? QFileInfo(currentFileUrl.path()).canonicalPath() + QLatin1Char('/') : QString();
+    const QString localFilePathIfAny = currentFileUrl.isLocalFile() ? QFileInfo(currentFileUrl.path()).canonicalPath() + QLatin1Char('/') : QStandardPaths::writableLocation(QStandardPaths::DocumentsLocation);
     const QString newFileName = localFilePathIfAny + getSuggestedFileNameForSignedFile(currentFileUrl.fileName(), mimeType.preferredSuffix());
 
     return QFileDialog::getSaveFileName(pageView, i18n("Save Signed File As"), newFileName, mimeTypeFilter);
@@ -424,7 +466,6 @@ SelectCertificateDialog::SelectCertificateDialog(QWidget *parent)
     , ui {std::make_unique<Ui_SelectCertificateDialog>()}
 {
     ui->setupUi(this);
-    ui->list->setItemDelegate(new KeyDelegate(ui->list));
 }
 SelectCertificateDialog::~SelectCertificateDialog() = default;
 
@@ -460,6 +501,9 @@ void KeyDelegate::paint(QPainter *painter, const QStyleOptionViewItem &option, c
 
     auto textRect = option.rect;
     int textMargin = style->pixelMetric(QStyle::PM_FocusFrameHMargin, &option, option.widget) + 1;
+    if (showIcon) {
+        textRect.adjust(textRect.height() + textMargin, 0, 0, 0); // make space for icon
+    }
     textRect.adjust(textMargin, 0, -textMargin, 0);
 
     QRect topHalf {textRect.x(), textRect.y(), textRect.width(), textRect.height() / 2};
@@ -468,6 +512,11 @@ void KeyDelegate::paint(QPainter *painter, const QStyleOptionViewItem &option, c
     style->drawItemText(painter, topHalf, (option.displayAlignment & Qt::AlignVertical_Mask) | Qt::AlignLeft, option.palette, true, index.data(Qt::DisplayRole).toString());
     style->drawItemText(painter, bottomHalf, (option.displayAlignment & Qt::AlignVertical_Mask) | Qt::AlignRight, option.palette, true, index.data(Qt::UserRole + 1).toString());
     style->drawItemText(painter, bottomHalf, (option.displayAlignment & Qt::AlignVertical_Mask) | Qt::AlignLeft, option.palette, true, index.data(Qt::UserRole).toString());
+    if (showIcon) {
+        if (auto icon = index.data(Qt::DecorationRole).value<QIcon>(); !icon.isNull()) {
+            icon.paint(painter, QRect(option.rect.topLeft(), QSize(textRect.height(), textRect.height())));
+        }
+    }
 }
 }
 
