@@ -28,7 +28,10 @@
 #include <KRecentFilesAction>
 #include <KSharedConfig>
 #include <KStandardAction>
+#ifndef Q_OS_WIN
 #include <KStartupInfo>
+#include <KWindowInfo>
+#endif
 #include <KToggleFullScreenAction>
 #include <KToolBar>
 #include <KUrlMimeData>
@@ -45,12 +48,13 @@
 #include <QMenuBar>
 #include <QMimeData>
 #include <QObject>
+#include <QPointer>
 #include <QScreen>
 #include <QTabBar>
 #include <QTabWidget>
 #include <QTimer>
 #ifdef WITH_KACTIVITIES
-#include <KActivities/ResourceInstance>
+#include <PlasmaActivities/ResourceInstance>
 #endif
 
 #include <kio_version.h>
@@ -70,6 +74,21 @@ static const char *const SESSION_TAB_KEY = "ActiveTab";
 static constexpr char SIDEBAR_LOCKED_KEY[] = "LockSidebar";
 static constexpr char SIDEBAR_VISIBLE_KEY[] = "ShowSidebar";
 
+class ResizableStackedWidget : public QStackedWidget
+{
+    Q_OBJECT
+
+public:
+    QSize sizeHint() const override
+    {
+        return currentWidget()->sizeHint();
+    }
+    QSize minimumSizeHint() const override
+    {
+        return currentWidget()->minimumSizeHint();
+    }
+};
+
 /**
  * Groups sidebar containers in a QDockWidget.
  *
@@ -90,6 +109,10 @@ public:
 
         m_stackedWidget = new QStackedWidget;
         setWidget(m_stackedWidget);
+        // It seems that without requesting a specific minimum size, Qt
+        // somehow calculates a (0,-1) minimum size, and then Qt gets angry
+        // that negative sizes is not possible.
+        setMinimumSize(10, 10);
     }
 
     bool isLocked() const
@@ -151,9 +174,6 @@ Shell::Shell(const QString &serializedOptions)
     : KParts::MainWindow()
     , m_menuBarWasShown(true)
     , m_toolBarWasShown(true)
-#ifndef Q_OS_WIN
-    , m_activityResource(nullptr)
-#endif
     , m_isValid(true)
 {
     setObjectName(QStringLiteral("okular::Shell#"));
@@ -184,7 +204,7 @@ Shell::Shell(const QString &serializedOptions)
     KParts::ReadWritePart *const firstPart = m_partFactory->create<KParts::ReadWritePart>(this);
     if (firstPart) {
         // Setup the central widget
-        m_centralStackedWidget = new QStackedWidget();
+        m_centralStackedWidget = new ResizableStackedWidget();
         setCentralWidget(m_centralStackedWidget);
 
         // Setup the welcome screen
@@ -223,6 +243,12 @@ Shell::Shell(const QString &serializedOptions)
             if (m_showSidebarAction && m_centralStackedWidget->currentWidget() != m_welcomeScreen) {
                 m_showSidebarAction->setChecked(visible);
             }
+            if (m_centralStackedWidget->currentWidget() == m_welcomeScreen) {
+                // MainWindow tries hard to make its child dockwidgets shown, but during
+                // welcome screen we don't want to see the sidebar,
+                // so try a bit more to actually hide it.
+                m_sidebar->hide();
+            }
         });
         addDockWidget(Qt::LeftDockWidgetArea, m_sidebar);
 
@@ -279,7 +305,7 @@ Shell::Shell(const QString &serializedOptions)
 
 void Shell::reloadAllXML()
 {
-    for (const TabState &tab : qAsConst(m_tabs)) {
+    for (const TabState &tab : std::as_const(m_tabs)) {
         tab.part->reloadXML();
     }
 }
@@ -336,7 +362,7 @@ Shell::~Shell()
 {
     if (!m_tabs.empty()) {
         writeSettings();
-        for (const TabState &tab : qAsConst(m_tabs)) {
+        for (const TabState &tab : std::as_const(m_tabs)) {
             tab.part->closeUrl(false);
         }
         m_tabs.clear();
@@ -390,10 +416,12 @@ bool Shell::canOpenDocs(int numDocs, int desktop)
         return false;
     }
 
-    const KWindowInfo winfo(window()->effectiveWinId(), KWindowSystem::WMDesktop);
+#ifndef Q_OS_WIN
+    const KWindowInfo winfo(window()->effectiveWinId(), NET::WMDesktop);
     if (winfo.desktop() != desktop) {
         return false;
     }
+#endif
 
     return true;
 }
@@ -427,11 +455,7 @@ void Shell::openUrl(const QUrl &url, const QString &serializedOptions)
         if (!isstdin) {
             if (openOk) {
 #ifdef WITH_KACTIVITIES
-                if (!m_activityResource) {
-                    m_activityResource = new KActivities::ResourceInstance(window()->winId(), this);
-                }
-
-                m_activityResource->setUri(url);
+                KActivities::ResourceInstance::notifyAccessed(url);
 #endif
                 m_recent->addUrl(url);
             } else {
@@ -561,7 +585,7 @@ void Shell::saveProperties(KConfigGroup &group)
 
     // Gather lists of settings to preserve
     QStringList urls;
-    for (const TabState &tab : qAsConst(m_tabs)) {
+    for (const TabState &tab : std::as_const(m_tabs)) {
         urls.append(tab.part->url().url());
     }
     group.writePathEntry(SESSION_URL_KEY, urls);
@@ -603,6 +627,9 @@ void Shell::fileOpen()
     if (curPart->url().isLocalFile()) {
         startDir = KIO::upUrl(curPart->url());
     }
+    if (startDir.isEmpty() || (startDir == QUrl::fromLocalFile(QDir::rootPath()))) {
+        startDir = QUrl::fromLocalFile(QStandardPaths::writableLocation(QStandardPaths::DocumentsLocation));
+    }
 
     QPointer<QFileDialog> dlg(new QFileDialog(this));
     dlg->setDirectoryUrl(startDir);
@@ -619,7 +646,7 @@ void Shell::fileOpen()
     const bool useMimeTypeFilters = qgetenv("XDG_CURRENT_DESKTOP").toLower() == "kde";
     if (useMimeTypeFilters) {
         QStringList mimetypes;
-        for (const QString &mimeName : qAsConst(m_fileformats)) {
+        for (const QString &mimeName : std::as_const(m_fileformats)) {
             QMimeType mimeType = mimeDatabase.mimeTypeForName(mimeName);
             mimetypes << mimeType.name();
         }
@@ -628,7 +655,7 @@ void Shell::fileOpen()
     } else {
         QSet<QString> globPatterns;
         QMap<QString, QStringList> namedGlobs;
-        for (const QString &mimeName : qAsConst(m_fileformats)) {
+        for (const QString &mimeName : std::as_const(m_fileformats)) {
             QMimeType mimeType = mimeDatabase.mimeTypeForName(mimeName);
             const QStringList globs(mimeType.globPatterns());
             if (globs.isEmpty()) {
@@ -665,11 +692,15 @@ void Shell::fileOpen()
 
 void Shell::tryRaise(const QString &startupId)
 {
+#ifndef Q_OS_WIN
     if (KWindowSystem::isPlatformWayland()) {
         KWindowSystem::setCurrentXdgActivationToken(startupId);
     } else if (KWindowSystem::isPlatformX11()) {
         KStartupInfo::setNewStartupId(window()->windowHandle(), startupId.toUtf8());
     }
+#else
+    Q_UNUSED(startupId);
+#endif
 
     KWindowSystem::activateWindow(window()->windowHandle());
 }
@@ -757,8 +788,8 @@ bool Shell::queryClose()
 {
     if (m_tabs.count() > 1) {
         const QString dontAskAgainName = QStringLiteral("ShowTabWarning");
-        KMessageBox::ButtonCode dummy = KMessageBox::Yes;
-        if (shouldBeShownYesNo(dontAskAgainName, dummy)) {
+        KMessageBox::ButtonCode dummy = KMessageBox::PrimaryAction;
+        if (KMessageBox::shouldBeShownTwoActions(dontAskAgainName, dummy)) {
             QDialog *dialog = new QDialog(this);
             dialog->setWindowTitle(i18n("Confirm Close"));
 
@@ -778,7 +809,7 @@ bool Shell::queryClose()
                                                               KMessageBox::Notify);
 
             if (!checkboxResult) {
-                saveDontShowAgainYesNo(dontAskAgainName, dummy);
+                KMessageBox::saveDontShowAgainTwoActions(dontAskAgainName, dummy);
             }
 
             if (result != QDialogButtonBox::Yes) {
